@@ -62,7 +62,9 @@ from .usecases import (
     ChildMonitoringUseCase,
     GenderDetectionUseCase,
     ConcreteCrackUseCase,
-    FashionDetectionUseCase
+    FashionDetectionUseCase,
+    WarehouseObjectUseCase,
+    ShoppingCartUseCase
 
 
 )
@@ -159,6 +161,8 @@ class PostProcessor:
         registry.register_use_case("security", "weapon_detection", WeaponDetectionUseCase)
         registry.register_use_case("general", "concrete_crack_detection", ConcreteCrackUseCase)
         registry.register_use_case("retail", "fashion_detection", FashionDetectionUseCase)
+        registry.register_use_case("retail", "warehouse_object_segmentation", WarehouseObjectUseCase)
+        registry.register_use_case("retail", "shopping_cart_analysis", ShoppingCartUseCase)
         
         logger.debug("Registered use cases with registry")
     
