@@ -30,7 +30,7 @@ class FaceEmotionConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
     
     # emotion confidence thresholds
-    confidence_threshold: float = 0.5
+    confidence_threshold: float = 0.3
 
     
     emotion_categories: List[str] = field(
@@ -580,8 +580,8 @@ class FaceEmotionUseCase(BaseProcessor):
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
-            "type": "face_emotion",
-            "category": "general",
+            "type": "face_tracking",
+            "category": "face",
             "count": total_emotions,
             "insights": insights,
             "summary": summary,
